compileCommand method
SQLite cannot add a primary key to an existing table.
Implementation
@override
String compileCommand(String table, SchemaCommand command) {
if (command is PrimaryCommand) {
throw DatabaseException(
'SQLite cannot add a primary key to an existing table; declare it '
'when creating the table.',
);
}
return super.compileCommand(table, command);
}